@@ -12,20 +12,21 @@ def main_usage():
     print("\n\033[1;33;40mProgram: \033[0m\033[1;35;40m featurExtract \033[1;31;40m(pipeline for genomic feature extract)\033[0m")
     print("\033[1;33;40mVersion: \033[0m\033[1;32;40m %s\033[0m"%(__version__))
     print("\033[1;33;40mContact: \033[0m\033[1;32;40m Sitao Zhu <zhusitao1990@163.com>\033[0m")
-    print("\033[1;33;40mUsage  : \033[0m\033[1;35;40m featurExtract\033[0m \033[1;31;40m<command>\033[0m")
+    print("\033[1;33;40mUsage  : \033[0m\033[1;35;40m featurExtract\033[0m \033[1;31;40m<command> [parameters] \033[0m")
     print("\033[1;33;40mCommand: \033[0m")
-    sub_usage(["create  ", "create  database for GTF or GFF"])
-    sub_usage(["CDS     ", "extract CDS for genome or gene"])
-    sub_usage(["cdna    ", "extract cdna (refMrna) sequence fo genome or gene"])
-    sub_usage(["dORF    ", "extract dORF for genome or gene"])
+    sub_usage(["create  ", "create database for GTF or GFF"])
+    sub_usage(["coverage", "read coverage by transcript models"])
+    sub_usage(["CDS     ", "extract CDS for gene or genome"])
+    sub_usage(["cdna    ", "extract cdna (refMrna) sequence fo gene or genome"])
+    sub_usage(["dORF    ", "extract downstream (dORF) for gene or genome"])
     sub_usage(["exon    ", "extract exon for transcript"])
-    sub_usage(["gene    ", "extract gene sequence fo genome or gene"])
-    sub_usage(["IGR     ", "extract intergenic region(IGR) between genes"])
+    sub_usage(["gene    ", "extract gene sequence fo gene or genome"])
+    sub_usage(["IGR     ", "extract intergenic region (IGR) between genes"])
     sub_usage(["intron  ", "extract intron for transcript"])
     sub_usage(["mRNA    ", "extract mature messager RNA for transcript"])
-    sub_usage(["promoter", "extract promoter for genome or gene"])
-    sub_usage(["uORF    ", "extract uORF for genome or gene"])
-    sub_usage(["UTR     ", "extract UTR for genome or gene"])
+    sub_usage(["promoter", "extract promoter for gene or genome"])
+    sub_usage(["uORF    ", "extract upstream ORF (uORF) for gene or genome"])
+    sub_usage(["UTR     ", "extract untranslated region (UTR) for gene or genome"])
     
     sys.exit(1)
 
